@@ -25,11 +25,11 @@ class TestCli(unittest.TestCase):
         output = check_output('{} full_name'.format(cmd), shell=True)
         self.assertTrue("\"data\": \"device.domain.localhost\"" in output, output)
 
-    def test_short_name_activated(self):
+    def test_user_domain_activated(self):
 
         copy_conf('domain.json')
-        output = check_output('{} short_name'.format(cmd), shell=True)
-        self.assertTrue("\"data\": \"domain.localhost\"" in output, output)
+        output = check_output('{} user_domain'.format(cmd), shell=True)
+        self.assertTrue("\"data\": \"domain\"" in output, output)
 
     def test_cron(self):
 
